@@ -1,7 +1,3 @@
-__all__ = (
-    "console"
-)
-
 class console:
 	def log(*other) -> None:
 	    print(' '.join([str(i) for i in other]))
\ No newline at end of file
